<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Tambah Plugin</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Cari:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Tambah Widget</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(hanya satu instansi yang dapat berjalan pada satu waktu)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Konfigurasi Panel</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Widget</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Konfigurasi panel</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Ukuran</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Ukuran:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="109"/>
        <location filename="../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Ukuran ikon:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Panjang:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Nilai piksel negatif menentukan berapa piksel yang kurang pada panjang panel dari yang tersedia pada ruang layar.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Contoh &quot;Panjang&quot; diatur -100px, ukuran layar 1000px, maka panjang panel yang sebenarnya adalah 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Penjajaran &amp;&amp; posisi</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="262"/>
        <location filename="../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Nol berarti tanpa animasi</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="288"/>
        <location filename="../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Durasi animasi:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="173"/>
        <source>Rows:</source>
        <translation>Baris:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="219"/>
        <location filename="../config/configpanelwidget.cpp" line="206"/>
        <source>Left</source>
        <translation>Kiri</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="224"/>
        <location filename="../config/configpanelwidget.cpp" line="207"/>
        <location filename="../config/configpanelwidget.cpp" line="213"/>
        <source>Center</source>
        <translation>Tengah</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="229"/>
        <location filename="../config/configpanelwidget.cpp" line="208"/>
        <source>Right</source>
        <translation>Kanan</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>Sembunyi-otomatis</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="301"/>
        <location filename="../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Nol berarti tanpa jeda</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Tampilkan dengan jeda:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Jangan biarkan jendela yang dimaksimalkan masuk di bawah jendela panel</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation>Cadangan ruang pada layar</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>Gaya kustom</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>Warna fonta:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>Warna latar belakang:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>Opasitas latar belakang:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Compositing dibutuhkan untuk transparasi panel.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>Gambar latar belakang:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="561"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation>Solusi parsial untuk gaya widget yang
tidak dapat memberikan tema terpisah pada panel.

Anda mungkin juga ingin menonaktifkan:

Konfigurasi Penampilan LXQt →
Tema Ikon →
Warnai ikon berdasarkan gaya widget (palette)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="571"/>
        <source>Override icon &amp;theme</source>
        <translation>Ganti &amp;tema ikon</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="586"/>
        <source>Icon theme for panels:</source>
        <translation>Tema ikon untuk panel:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Penjajaran:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>Posisi:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="172"/>
        <source>Top of desktop</source>
        <translation>Atas desktop</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="173"/>
        <source>Left of desktop</source>
        <translation>Kiri desktop</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="174"/>
        <source>Right of desktop</source>
        <translation>Kanan desktop</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="175"/>
        <source>Bottom of desktop</source>
        <translation>Bawah desktop</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="184"/>
        <source>Top of desktop %1</source>
        <translation>Atas desktop %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="185"/>
        <source>Left of desktop %1</source>
        <translation>Kiri desktop %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="186"/>
        <source>Right of desktop %1</source>
        <translation>Kanan desktop %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="187"/>
        <source>Bottom of desktop %1</source>
        <translation>Bawah desktop %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="212"/>
        <source>Top</source>
        <translation>Atas</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="214"/>
        <source>Bottom</source>
        <translation>Bawah</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="430"/>
        <location filename="../config/configpanelwidget.cpp" line="446"/>
        <source>Pick color</source>
        <translation>Pilih warna</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="464"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Gambar (*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="464"/>
        <source>Pick image</source>
        <translation>Pilih gambar</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Konfigurasi Panel</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Catatan: perubahan yang dibuat pada halaman ini tidak dapat dipulihkan.</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Pindah keatas</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Pindah kebawah</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Konfigurasi</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1068"/>
        <location filename="../lxqtpanel.cpp" line="1094"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1097"/>
        <source>Configure Panel</source>
        <translation>Konfigurasi Panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1102"/>
        <source>Manage Widgets</source>
        <translation>Kelola Widget</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1108"/>
        <source>Add New Panel</source>
        <translation>Tambah Panel Baru</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1115"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Hapus Panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1120"/>
        <source>Lock This Panel</source>
        <translation>Kunci Panel Ini</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1273"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Hapus Panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1274"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Penghapusan panel tidak dapat dibatalkan.
Apakah Anda ingin menghapus panel ini?</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="411"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Konfigurasi &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="416"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Pindah &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="424"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Hapus &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Gunakan berkas konfigurasi alternatif.</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Berkas konfigurasi</translation>
    </message>
</context>
</TS>
